@@ -36,6 +36,7 @@ class mainDialog:
         xml.get_widget('selection-label').set_markup('<b>'
                                                      + SELECTION_MESSAGE
                                                      + '</b>')
+        ok_button = xml.get_widget('ok-button')
         # Initialize alternatives list.
         self.radio_buttons = {}
         self.alternatives = {}
@@ -49,13 +50,17 @@ class mainDialog:
                                                            pretty_names[java])
             radio_vbox.pack_start(self.radio_buttons[java], False, False, 0)
             self.radio_buttons[java].show()
+            self.radio_buttons[java].connect("toggled", lambda *x:
+                                             ok_button.set_sensitive(True))
             self.alternatives[self.radio_buttons[java]] = java
         # Show default alternative as currently selected and give it
         # keyboard focus.
         self.radio_buttons[default_java].set_active(True)
         self.radio_buttons[default_java].grab_focus()
-        xml.get_widget('close-button').connect('clicked',
-                                               self.close_button_clicked)
+        ok_button.connect('clicked', self.ok_button_clicked)
+        ok_button.set_sensitive(False)
+        xml.get_widget('cancel-button').connect('clicked',
+                                                self.cancel_button_clicked)
         self.dialog.connect('delete-event', self.dialog_delete_event)
         self.dialog.connect('hide', gtk.main_quit)
         self.dialog.set_icon_from_file('/usr/share/pixmaps/'
@@ -66,7 +71,7 @@ class mainDialog:
     def dialog_delete_event(self, *args):
         gtk.main_quit()
 
-    def close_button_clicked(self, button):
+    def ok_button_clicked(self, button):
         for radio_button in self.radio_buttons.values():
             if radio_button.get_active():
                 switch_java(self.alternatives[radio_button])
@@ -74,6 +79,10 @@ class mainDialog:
         self.dialog.hide()
         gtk.main_quit()
 
+    def cancel_button_clicked(self, button):
+        self.dialog.hide()
+        gtk.main_quit()
+
     def show_dialog(self, message):
         dialog = gtk.MessageDialog(None,
                                    gtk.DIALOG_MODAL
